import bb.cascades 1.3
import "../Items"

import LocaleHandler 1.0


Container {
	leftPadding: 10.0
	rightPadding: 10.0
	bottomPadding: 10.0
	topPadding: 10.0

	horizontalAlignment: HorizontalAlignment.Fill
	verticalAlignment: VerticalAlignment.Fill

	property bool empty: false

	layout: StackLayout {
	    orientation: LayoutOrientation.TopToBottom
    }

    layoutProperties: StackLayoutProperties {
    }
    
    ListView {
        id: bookmarksList
        objectName: "bookmarksList"
    
		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Top

        signal actionMultiItemsClicked(string action, variant indexPath)
        signal actionItemClicked(string action, variant indexPath)

		attachedObjects: [
			GroupDataModel {
				id: bookmarksModel
				objectName: "bookmarksModel"

				sortingKeys: ["id"]
				sortedAscending: false

				grouping: ItemGrouping.None
			},
			LocaleHandler {
				onLanguageChanged: {
					bookmarksList.updateMultiStatus();
				}
			}
		]
    
		layout: StackListLayout {
			headerMode: ListHeaderMode.None
            orientation: LayoutOrientation.TopToBottom
        }

        layoutProperties: StackLayoutProperties {
        }
    
		dataModel: bookmarksModel

        listItemComponents: [
            ListItemComponent {
                type: "item"

				StandardListItem {
					id: bookmarkItemContainer

					title: ListItemData.name
					imageSource: "asset:///images/icons/folder.png"
					description: ListItemData.description

					contextActions: [
						ActionSet {
							ActionItem {
								title: qsTr("Open") + Retranslate.onLanguageChanged
								imageSource: "asset:///images/dock/openwith.png"
								enabled: ListItemData.openable
								onTriggered: {
									bookmarkItemContainer.ListItem.view.runAction("ACTION_OPEN", bookmarkItemContainer.ListItem.indexPath);
								}
							}

							MultiSelectActionItem {
								multiSelectHandler: bookmarkItemContainer.ListItem.view.multiSelectHandler
								onTriggered: {
									multiSelectHandler.active;    
								} 
							}

							DeleteActionItem {
								title: qsTr("Delete") + Retranslate.onLanguageChanged
								onTriggered: {
									bookmarkItemContainer.ListItem.view.runAction("ACTION_DELETE", bookmarkItemContainer.ListItem.indexPath);
								}
							}
						}
					]
				}
            }
        ]

		function itemType(data, indexPath) {
			return "item";
		}


        multiSelectHandler {
            status: qsTr("None selected")
            
            actions: [
				DeleteActionItem {
					title: qsTr("Delete") + Retranslate.onLanguageChanged
					onTriggered: {
						bookmarksList.runActionMulti("ACTION_DELETE", bookmarksList.selectionList());
					}
				}
	        ]
		    
            onActiveChanged: {
                clearSelection();
            }
        }

		onTriggered: {
			clearSelection();
			select(indexPath);
		}

        onSelectionChanged: {
            // Call a function to update the number of selected items in the multi-select view.
            updateMultiStatus();
        }
        
		function updateMultiStatus() {
			if (selectionList().length > 1) {
				multiSelectHandler.status = qsTr("%1 items selected").arg(selectionList().length);
			} else if (selectionList().length == 1) {
				multiSelectHandler.status = qsTr("1 item selected");
			} else {
				multiSelectHandler.status = qsTr("None selected");
			}
		}

        function runActionMulti(action, indexPath) {
            console.log("action multi detected !", action, indexPath);
            
            actionMultiItemsClicked(action, indexPath);
        }

        function runAction(action, indexPath) {
            console.log("action detected !", action, indexPath);
            
            actionItemClicked(action, indexPath);
        }
    }
}

