import bb.cascades 1.3
import "../Items"

import LocaleHandler 1.0
import com.playcloud.tasks 1.0


Container {
	leftPadding: 10.0
	rightPadding: 10.0
	bottomPadding: 10.0
	topPadding: 10.0

	horizontalAlignment: HorizontalAlignment.Fill
	verticalAlignment: VerticalAlignment.Fill

	layout: StackLayout {
	    orientation: LayoutOrientation.TopToBottom
    }

    layoutProperties: StackLayoutProperties {
    }
    
    ListView {
        id: tasksList
        objectName: "tasksList"
    
		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Top

        signal actionMultiItemsClicked(string action, variant indexPath)
        signal actionItemClicked(string action, variant indexPath)

		attachedObjects: [
			TasksModel {
				id: tasksModel
				objectName: "tasksModel"

				sortingKeys: ["id"]
				sortedAscending: false

				grouping: ItemGrouping.None
			},
			LocaleHandler {
				onLanguageChanged: {
					tasksList.updateMultiStatus();
				}
			}
		]
    
		layout: StackListLayout {
			headerMode: ListHeaderMode.None
            orientation: LayoutOrientation.TopToBottom
        }

        layoutProperties: StackLayoutProperties {
        }
    
		dataModel: tasksModel

        listItemComponents: [
            ListItemComponent {
                type: "transfer"
                TransferTaskItem {
                }
            },
            ListItemComponent {
                type: "open"
                OpenTaskItem {
                }
            },
            ListItemComponent {
                type: "print"
                PrintTaskItem {
                }
            }
        ]

		function itemType(data, indexPath) {
			if (data.type == "transfer")
				return "transfer";
			else if (data.type == "open")
				return "open";
			else
				return "print";
		}


        multiSelectHandler {
            status: qsTr("None selected")
            
            actions: [
	            ActionItem {
	                title: qsTr("Pause") + Retranslate.onLanguageChanged
                	imageSource: "asset:///images/dock/pause.png"
	                onTriggered: {
		            	tasksList.runActionMulti("ACTION_PAUSE", tasksList.selectionList()); 
	                }
	            },
	            ActionItem {
	                title: qsTr("Resume") + Retranslate.onLanguageChanged
                	imageSource: "asset:///images/dock/play.png"
	                onTriggered: {
		            	tasksList.runActionMulti("ACTION_RESUME", tasksList.selectionList()); 
	                }
	            },
				ActionItem {
					title: qsTr("Stop") + Retranslate.onLanguageChanged
                	imageSource: "asset:///images/dock/stop.png"
					onTriggered: {
						tasksList.runActionMulti("ACTION_STOP", tasksList.selectionList());
					}
				},
				DeleteActionItem {
					title: qsTr("Cancel") + Retranslate.onLanguageChanged
					onTriggered: {
					   tasksList.runActionMulti("ACTION_CANCEL", tasksList.selectionList()); 
					}
				}
	        ]
		    
            onActiveChanged: {
                clearSelection();
            }
        }

		onTriggered: {
			clearSelection();
			select(indexPath);
		}

        onSelectionChanged: {
            // Call a function to update the number of selected items in the multi-select view.
            updateMultiStatus();
        }
        
		function updateMultiStatus() {
			if (selectionList().length > 1) {
				multiSelectHandler.status = qsTr("%1 items selected").arg(selectionList().length);
			} else if (selectionList().length == 1) {
				multiSelectHandler.status = qsTr("1 item selected");
			} else {
				multiSelectHandler.status = qsTr("None selected");
			}
		}

        function runActionMulti(action, indexPath) {
            console.log("action multi detected !", action, indexPath);
            
            actionMultiItemsClicked(action, indexPath);
        }

        function runAction(action, indexPath) {
            console.log("action detected !", action, indexPath);
            
            actionItemClicked(action, indexPath);
        }
    }

	function clear() {
		tasksModel.autoclear();
	}
}

