import bb.cascades 1.3
import "Items"

import LocaleHandler 1.0
//import myLibrary 1.0

Container {
	leftPadding: 0.0
	rightPadding: 0.0
	bottomPadding: 10.0
	topPadding: 0.0

	horizontalAlignment: HorizontalAlignment.Fill
	verticalAlignment: VerticalAlignment.Fill

	layout: StackLayout {
	    orientation: LayoutOrientation.TopToBottom
    }

    layoutProperties: StackLayoutProperties {
    }

	attachedObjects: [
		GroupDataModel {
			id: groupDataModel 
			objectName: "groupDataModel"

			sortingKeys: ["category", "name"]

			grouping: ItemGrouping.ByFullValue
		},
		LocaleHandler {
			onLanguageChanged: {
				filesList.updateMultiStatus();
			}
		}
	]
    
    ListView {
        id: filesList
        objectName: "filesList"

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Top

        scrollRole: ScrollRole.Main

        signal actionMultiItemsClicked(string action, variant indexPath)
        signal actionItemClicked(string action, variant indexPath)
		signal zoomFactorChanged(int zoom)

		layout: GridListLayout {
			id: filesGridLayout
			objectName: "filesGridLayout"
            headerMode:  ListHeaderMode.Standard
			columnCount: 5
            cellAspectRatio: 1.0
            horizontalCellSpacing: 6.0
            verticalCellSpacing: 6.0
            spacingBeforeHeader: 8.0
            spacingAfterHeader: 6.0
            property int initialScale: 5
		}

        layoutProperties: StackLayoutProperties {
            spaceQuota: -1.0
        }
    
		dataModel: groupDataModel

        listItemComponents: [
            ListItemComponent {
                type: "header"
                CategoryItem {
                }
            },
            ListItemComponent {
                type: "item"
                TileItem {
                }
            }
        ]

		function itemType(data, indexPath) {
			if (indexPath.length == 1)
				return "header";
			else
				return "item";
		}

        multiSelectHandler {
            status: qsTr("None selected")            

            actions: [
	            ActionItem {
	                title: qsTr("Copy to") + Retranslate.onLanguageChanged
	                imageSource: "asset:///images/dock/copy.png"
	                onTriggered: {
		               filesList.runActionMulti("ACTION_COPY", filesList.selectionList()); 
	                }
	            },
	            ActionItem {
	                title: qsTr("Move to") + Retranslate.onLanguageChanged
	                imageSource: "asset:///images/dock/move.png"
	                onTriggered: {
		               filesList.runActionMulti("ACTION_MOVE", filesList.selectionList()); 
	                }
	            },
//	            ActionItem {
//					enabled: false
//	                title: qsTr("Zip") + Retranslate.onLanguageChanged
//	                imageSource: "asset:///images/dock/zip.png"
//	                onTriggered: {
//		               filesList.runActionMulti("ACTION_ZIP", filesList.selectionList()); 
//	                }
//	            },
//	            ActionItem {
//					enabled: false
//	                title: qsTr("Crypt") + Retranslate.onLanguageChanged
//	                imageSource: "asset:///images/dock/crypt.png"
//	                onTriggered: {
//		               filesList.runActionMulti("ACTION_CRYPT", filesList.selectionList()); 
//	                }
//	            },
				ActionItem {
					title: qsTr("Add bookmark") + Retranslate.onLanguageChanged
					imageSource: "asset:///images/dock/addbookmarks.png"
					onTriggered: {
		               filesList.runActionMulti("ACTION_BOOKMARKS", filesList.selectionList()); 
					}
				},
				DeleteActionItem {
					title: qsTr("Delete") + Retranslate.onLanguageChanged
					onTriggered: {
						filesList.runActionMulti("ACTION_DELETE", filesList.selectionList()); 
					}
				}
	        ]

            onActiveChanged: {
                clearSelection();
            }
        }

		gestureHandlers: [
			PinchHandler {
				onPinchStarted: {
					filesGridLayout.initialScale = filesGridLayout.columnCount;
				}

				onPinchUpdated: {
					var scale = filesGridLayout.initialScale - Math.round((event.pinchRatio-1) * 3.2);
					if ((scale > 1) && (scale < 7)) {
						filesGridLayout.columnCount = scale;
					}
				}

				onPinchEnded: {
					filesList.zoomFactorChanged(filesGridLayout.columnCount);
				}
			}
		]

		onTriggered: {
			clearSelection();
			select(indexPath);
		}

        onSelectionChanged: {
			if (indexPath.length == 1)
				select(indexPath, false);

            // Call a function to update the number of selected items in the multi-select view.
            updateMultiStatus();
        }

        function updateMultiStatus() {
			if (selectionList().length > 1) {
				multiSelectHandler.status = qsTr("%1 items selected").arg(selectionList().length);
			} else if (selectionList().length == 1) {
				multiSelectHandler.status = qsTr("1 item selected");
			} else {
				multiSelectHandler.status = qsTr("None selected");
			}
		}
        
        function runActionMulti(action, indexPath) {
            console.log("action multi detected !", action, indexPath);
            
            actionMultiItemsClicked(action, indexPath);
        }

        function runAction(action, indexPath) {
            console.log("action detected !", action, indexPath);
            
            actionItemClicked(action, indexPath);
        }
    }
}

