import bb.cascades 1.3

Container {
    id: usersContainer
    opacity: 1.0
    preferredWidth: 1440.0

    layout: DockLayout {
    }

    Container {
        id: background
        background: Color.create("#00a7de")
        visible: false

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Fill

        layout: DockLayout {
        }
    }

	Divider {
		verticalAlignment: VerticalAlignment.Bottom
	}
        
    // The Item content an image and a text.
    Container {
		leftPadding: 0
		topPadding: 0.0
		bottomPadding: 0.0

		horizontalAlignment: HorizontalAlignment.Fill

        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        
        ImageView {
            preferredWidth: 180.0
            preferredHeight: 180.0

			minWidth: preferredWidth
			minHeight: preferredHeight
            
			horizontalAlignment: HorizontalAlignment.Center
			verticalAlignment: VerticalAlignment.Center

            // The image is bound to the data in models/recipemodel.xml image attribute.
            imageSource: "asset:///images/misc/contact.png"
        	scalingMethod: ScalingMethod.AspectFit
            
            layoutProperties: StackLayoutProperties {
            }
            
            leftMargin: 0.0
            rightMargin: 20.0
            bottomMargin: 0.0
            topMargin: 0.0
        }

		Container {
			horizontalAlignment: HorizontalAlignment.Fill
			verticalAlignment: VerticalAlignment.Center

			layout: StackLayout {
				orientation: LayoutOrientation.TopToBottom
			}

            leftMargin: 0.0
            rightMargin: 0.0
            bottomMargin: 0.0
            topMargin: 0.0
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.name
				leftMargin: 20.0

				horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.BodyText // BodyText SubtitleText SmallText
				}
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.googletype
				leftMargin: 20.0

				horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.SmallText // BodyText SubtitleText SmallText
					fontStyle: FontStyle.Italic
				}
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.status
				leftMargin: 20.0

				horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.SmallText // BodyText SubtitleText SmallText
					fontStyle: FontStyle.Italic
				}
			}
		}
    }
    

    contextActions: [
        ActionSet {
            title: ListItemData.name
            subtitle: qsTr("User permissions") + Retranslate.onLanguageChanged
            
            ActionItem {
                title: qsTr("Viewer") + Retranslate.onLanguageChanged
				enabled: ListItemData.viewable
                imageSource: "asset:///images/dock/viewer.png"
                onTriggered: {
                    usersContainer.ListItem.view.runAction("ACTION_VIEWER", usersContainer.ListItem.indexPath);
                }
            }
            
            ActionItem {
                title: qsTr("Commenter") + Retranslate.onLanguageChanged
				enabled: ListItemData.commentable
                imageSource: "asset:///images/dock/editor.png"
                onTriggered: {
                    usersContainer.ListItem.view.runAction("ACTION_COMMENTER", usersContainer.ListItem.indexPath);
                }
            }

            ActionItem {
                title: qsTr("Editor") + Retranslate.onLanguageChanged
				enabled: ListItemData.editable
                imageSource: "asset:///images/dock/editor.png"
                onTriggered: {
                    usersContainer.ListItem.view.runAction("ACTION_EDITOR", usersContainer.ListItem.indexPath);
                }
            }

            DeleteActionItem {
                title: qsTr("Delete") + Retranslate.onLanguageChanged
				enabled: ListItemData.removeable
                onTriggered: {
                    usersContainer.ListItem.view.runAction("ACTION_DELETE", usersContainer.ListItem.indexPath);
                }
            }
        }
    ]

    // Both the activation and selection of an item has the same visual appearance.
    function setHighlight (highlighted) {
        if (highlighted) {
//            usersContainer.opacity = 0.7;
            background.visible = true;
        } else {
//            usersContainer.opacity = 1.0;
            background.visible = false;
        }
    }

    // Signal handler for list item activation.    
    ListItem.onActivationChanged: {
		console.log("active changed");
        setHighlight (ListItem.active);
    }
    
    // Signal handler for list item selection.
    ListItem.onSelectionChanged: {
		console.log("select changed");
        setHighlight (ListItem.selected);
    }
    
    scaleX: 1.0
    scaleY: 1.0
}
