import bb.cascades 1.3

// Item component for the list presenting available recipes.
Container {
	id: printerContainer
    opacity: 1.0
    preferredWidth: 1440.0

    layout: DockLayout {
    }
    
    Container {
        id: background
        background: Color.create("#75b5d3")
        visible: false

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Fill

        layout: DockLayout {
        }
    }
        
    // The Item content an image and a text.
    Container {
		leftPadding: 3
		topPadding: 10.0
		bottomPadding: 10.0

		horizontalAlignment: HorizontalAlignment.Fill

        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        
        ImageView {
            preferredWidth: 240.0
            preferredHeight: 240.0
            
			horizontalAlignment: HorizontalAlignment.Center
			verticalAlignment: VerticalAlignment.Center

            imageSource: ListItemData.image
        	scalingMethod: ScalingMethod.AspectFit
            
            layoutProperties: StackLayoutProperties {
            }
            
            leftMargin: 10.0
            rightMargin: 20.0
            bottomMargin: 10.0
            topMargin: 10.0
        }
        
		Container {
			horizontalAlignment: HorizontalAlignment.Fill
			verticalAlignment: VerticalAlignment.Center

			layout: StackLayout {
				orientation: LayoutOrientation.TopToBottom
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.title
				leftMargin: 20.0

				horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.BodyText // BodyText SubtitleText SmallText
				}
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.description
				leftMargin: 20.0
                opacity: 0.8

                horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

                textStyle {
					base: SystemDefaults.TextStyles.SubtitleText // BodyText SubtitleText SmallText
//					color: Color.create("#393939")
				}
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.location
				leftMargin: 20.0
                opacity: 0.8

                horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.SubtitleText // BodyText SubtitleText SmallText
//					color: Color.create("#393939")
					fontStyle: FontStyle.Italic
				}
			}
		}
    }

    contextActions: [
        ActionSet {
            title: ListItemData.title
            subtitle: qsTr("Printer action") + Retranslate.onLanguageChanged

            ActionItem {
                title: qsTr("Print PDF") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/print.png"
            	enabled: ListItemData.printable
                onTriggered: {
                    printerContainer.ListItem.view.testPrintersItem(printerContainer.ListItem.indexPath, "pdf");
                }
            }

            ActionItem {
                title: qsTr("Print PS") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/print.png"
            	enabled: ListItemData.printable
                onTriggered: {
                    printerContainer.ListItem.view.testPrintersItem(printerContainer.ListItem.indexPath, "ps");
                }
            }

            ActionItem {
                title: qsTr("Print JPG") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/print.png"
            	enabled: ListItemData.printable
                onTriggered: {
                    printerContainer.ListItem.view.testPrintersItem(printerContainer.ListItem.indexPath, "jpg");
                }
            }

            DeleteActionItem {
                title: qsTr("Delete") + Retranslate.onLanguageChanged
                onTriggered: {
                    printerContainer.ListItem.view.deletePrintersItem(printerContainer.ListItem.indexPath, ListItemData.image);
                }
            }
        }
    ]
            
    

    function setHighlight(highlighted) {
        if(highlighted) {
            background.visible = true;
        } else {
            background.visible = false;
        }    
    }
    
    ListItem.onActivationChanged : {        
        setHighlight(ListItem.active);
    } 

    ListItem.onSelectionChanged : {
        setHighlight(ListItem.selected);
    }
}
