import bb.cascades 1.3

Container {
    id: taskContainer
    opacity: 1.0
    preferredWidth: 1440.0

    layout: DockLayout {
    }

    Container {
        id: background
        background: Color.create("#3d4750")
        visible: false

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Fill

        layout: DockLayout {
        }
    }
        
    Container {
		leftPadding: 3
		topPadding: 10.0

		horizontalAlignment: HorizontalAlignment.Fill
	
        layout: StackLayout {
            orientation: LayoutOrientation.TopToBottom
        }
	        
		Label {
			// The title is bound to the data in models/recipemodel.xml title attribute.
			text: ListItemData.destination
			leftMargin: 20.0

			horizontalAlignment: HorizontalAlignment.Left

			textStyle {
				base: SystemDefaults.TextStyles.BodyText // BodyText SubtitleText SmallText
				color: Color.create("#383a3b")
			}
		}

	    // The Item content an image and a text.
	    Container {
			horizontalAlignment: HorizontalAlignment.Fill
	
	        layout: StackLayout {
	            orientation: LayoutOrientation.LeftToRight
	        }
	        
	        ImageView {
	            preferredWidth: 120.0
	            preferredHeight: 120.0
	            minWidth: 120.0
	            minHeight: 120.0
	            
				horizontalAlignment: HorizontalAlignment.Center
				verticalAlignment: VerticalAlignment.Center
	
	            // The image is bound to the data in models/recipemodel.xml image attribute.
	            imageSource: ListItemData.icon
	        	scalingMethod: ScalingMethod.AspectFit
	            
	            layoutProperties: StackLayoutProperties {
	            }
	            
	            leftMargin: 10.0
	            rightMargin: 10.0
	        }
	        
			Container {
				horizontalAlignment: HorizontalAlignment.Fill
				verticalAlignment: VerticalAlignment.Center
	
				layout: StackLayout {
					orientation: LayoutOrientation.TopToBottom
				}
	
	            layoutProperties: StackLayoutProperties {
                    spaceQuota: 0.0
                }
	            
				Label {
					// The title is bound to the data in models/recipemodel.xml title attribute.
					text: ListItemData.name
					leftMargin: 20.0
	
					horizontalAlignment: HorizontalAlignment.Left
	
					textStyle {
						base: SystemDefaults.TextStyles.BodyText // BodyText SubtitleText SmallText
						color: Color.create("#383a3b")
					}
				}
	
				Label {
					// The title is bound to the data in models/recipemodel.xml title attribute.
					text: ListItemData.size
					leftMargin: 20.0
	
					horizontalAlignment: HorizontalAlignment.Left
	
					textStyle {
						base: SystemDefaults.TextStyles.SubtitleText // BodyText SubtitleText SmallText
	                	fontStyle: FontStyle.Italic
						color: Color.create("#383a3b")
					}
				}
	
				Label {
					// The title is bound to the data in models/recipemodel.xml title attribute.
					text: ListItemData.info
					leftMargin: 20.0
	
					horizontalAlignment: HorizontalAlignment.Left
	
					textStyle {
						base: SystemDefaults.TextStyles.SubtitleText // BodyText SubtitleText SmallText
	                	fontStyle: FontStyle.Italic
						color: Color.create("#383a3b")
					}
				}
	
				ProgressIndicator {
					id: progressIndicator
					objectName: "progressIndicator"
					visible: true

				    preferredWidth: 1440.0
					
					horizontalAlignment: HorizontalAlignment.Fill
					verticalAlignment: VerticalAlignment.Bottom
					
	                fromValue: 0.0
	                toValue: 100.0
	                value: ListItemData.progress
	                state: ListItemData.status
	            }
			}
		}
		
        Divider {
        }
    }
    

    contextActions: [
        ActionSet {
            title: ListItemData.name
            subtitle: qsTr("Task action") + Retranslate.onLanguageChanged
            
            ActionItem {
				enabled: ListItemData.pause
                title: qsTr("Pause") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/pause.png"
                onTriggered: {
                    taskContainer.ListItem.view.runAction("ACTION_PAUSE", taskContainer.ListItem.indexPath);
                }
            }
            
            ActionItem {
				enabled: ListItemData.resume
                title: qsTr("Resume") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/play.png"
                onTriggered: {
                    taskContainer.ListItem.view.runAction("ACTION_RESUME", taskContainer.ListItem.indexPath);
                }
            }

            ActionItem {
				enabled: ListItemData.stop
                title: qsTr("Stop") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/stop.png"
                onTriggered: {
                    taskContainer.ListItem.view.runAction("ACTION_STOP", taskContainer.ListItem.indexPath);
                }
            }

            MultiSelectActionItem {
                multiSelectHandler: taskContainer.ListItem.view.multiSelectHandler
                onTriggered: {
                    multiSelectHandler.active = true
                }
            }

            DeleteActionItem {
                title: qsTr("Cancel") + Retranslate.onLanguageChanged
                onTriggered: {
                    taskContainer.ListItem.view.runAction("ACTION_CANCEL", taskContainer.ListItem.indexPath);
                }
            }
        }
    ]

    // Both the activation and selection of an item has the same visual appearance.
    function setHighlight (highlighted) {
        if (highlighted) {
            background.visible = true;
        } else {
            background.visible = false;
        }
    }

    // Signal handler for list item activation.    
    ListItem.onActivationChanged: {
		console.log("active changed");
        setHighlight (ListItem.active);
    }
    
    // Signal handler for list item selection.
    ListItem.onSelectionChanged: {
		console.log("select changed");
        setHighlight (ListItem.selected);
    }
    
    scaleX: 1.0
    scaleY: 1.0
}
