import bb.cascades 1.3

Page {
    id: printUrlPage
    property alias url: printWebview.url
    property alias title: printWebview.title

//	actionBarVisibility: ChromeVisibility.Default
//	actionBarAutoHideBehavior: ActionBarAutoHideBehavior.HideOnScroll
	actionBarVisibility: ChromeVisibility.Visible
	actionBarAutoHideBehavior: ActionBarAutoHideBehavior.Disabled

    titleBar: TitleBar {
        title: qsTr("Print URL") + Retranslate.onLanguageChanged

        visibility: ChromeVisibility.Visible
        scrollBehavior: TitleBarScrollBehavior.Sticky
        selectedIndex: -1
    }
	
	content: Container {
		layout: DockLayout {

        }

        verticalAlignment: VerticalAlignment.Fill
        horizontalAlignment: HorizontalAlignment.Fill
        
			ScrollView {
				id: webviewContainer

				visible: false
				
                verticalAlignment: VerticalAlignment.Top
				horizontalAlignment: HorizontalAlignment.Fill
				
				scrollRole: ScrollRole.Main

				scrollViewProperties {
					scrollMode: ScrollMode.Both
					pinchToZoomEnabled: true
				}

				layoutProperties: StackLayoutProperties { 
//					spaceQuota: 1.0 
				}

				Container {
					background: Color.Black

					verticalAlignment: VerticalAlignment.Fill
					horizontalAlignment: HorizontalAlignment.Fill

					WebView {
						id: printWebview
						objectName: "printWebview"
					
						verticalAlignment: VerticalAlignment.Fill
						horizontalAlignment: HorizontalAlignment.Fill

						settings.defaultFontSize: 16
						settings.minimumFontSize: 16
						settings.zoomToFitEnabled: true
						settings.background: Color.White
						settings.defaultFontSizeFollowsSystemFontSize: true

						onMinContentScaleChanged: {
							webviewContainer.scrollViewProperties.minContentScale = minContentScale;
						}
		 
						onMaxContentScaleChanged: {
							webviewContainer.scrollViewProperties.maxContentScale = maxContentScale;
						}

						onLoadProgressChanged: {
							progressWebIndicator.value = loadProgress / 100.0
						}
						
						onNavigationHistoryChanged: {
						}

						onUrlChanged: {
							noticeWebRequest(url)
						}
					
						onLoadingChanged: {
							if (loadRequest.status == WebLoadStatus.Started)
								 progressWebIndicator.visible = true
							else if (loadRequest.status == WebLoadStatus.Succeeded)
								 progressWebIndicator.visible = false
							else if (loadRequest.status == WebLoadStatus.Failed)
								 progressWebIndicator.visible = false
						}
					}
				}
			}

		Container {
			horizontalAlignment: HorizontalAlignment.Fill
			verticalAlignment: VerticalAlignment.Bottom

			ProgressIndicator {
				id: progressWebIndicator
				visible: false

				horizontalAlignment: HorizontalAlignment.Center
			}

			TextField {
				id: urlTextField
				hintText: qsTr("Enter the URL to save") + Retranslate.onLanguageChanged
				inputMode: TextFieldInputMode.Url
				
				horizontalAlignment: HorizontalAlignment.Fill

				layoutProperties: StackLayoutProperties {
				}
				
				textStyle {
					base: SystemDefaults.TextStyles.BodyText
				}

				onTextChanged: {
				}

				input {
					submitKey: SubmitKey.Connect;

					onSubmitted: {
						console.log("On submitted " + urlTextField.text);

						printWebview.url = formatUrl(urlTextField.text);
						
                        webviewContainer.visible = true;
					}
				}
			}
		}
	}

	function noticeWebRequest(u) {
		urlTextField.text = u;
	}

	function formatUrl(u) {
		if (u.indexOf("http:") == 0)
			return u;
		if (u.indexOf("https:") == 0)
			return u;

		return "http://" + u;
	}

    actions: [
        ActionItem { 
			id: printActionItem
			objectName: "printActionItem"

            title: qsTr("Save to PDF") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/dock/print.png"

//            ActionBar.placement: ActionBarPlacement.OnBar
            ActionBar.placement: ActionBarPlacement.Signature
            
            onTriggered: {
            }
        }
    ]
}

