import bb.cascades 1.3
import "Items"

import bb.system 1.0
import LocaleHandler 1.0
import com.playcloud.settings 1.0


Page {
	id: settingsMainPage

	property string bbmstatus: ""
	property alias bbmupdateactivities: settingsBBMUpdateActivitiesCheckBox.checked
	property alias bbmlabel: settingsBBMStatusMessage.text

	property int cachesize: playcloud.getCacheSize() / (1024 * 1024);
	property int maxcachesize: playcloud.getMaximumCacheSize() / (1024 * 1024)

	attachedObjects: [
		LocaleHandler {
			onLanguageChanged: {
				settingsMainPage.updateCacheInfo();
				playcloud.checkBBMRegistrationAccess(false);
			}
		},
		ComponentDefinition {
			id: pageSettingsCloudDefinition
			source: "asset:///Settings/SettingsLocal.qml"
		},
		ComponentDefinition {
			id: pagePrinterCloudDefinition
			source: "asset:///Settings/Printer.qml"
		},
		ComponentDefinition {
			id: pageNewAccountDefinition
			source: "asset:///Settings/NewAccount.qml"
		},
		PasswordSystemDialog {
			id: passwordDialog
		}
	]

    titleBar: TitleBar {
        title: qsTr("Settings") + Retranslate.onLanguageChanged
    }

	content: Container {
		leftPadding: 15.0
		rightPadding: 15.0
		topPadding: 15.0
		bottomPadding: 15.0

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Fill

		layout: StackLayout {
		}
			
		layoutProperties: StackLayoutProperties {
		}

		SegmentedControl {
			horizontalAlignment: HorizontalAlignment.Center

			options: [
				Option {
					text: qsTr("General") + Retranslate.onLanguageChanged
					value: "general"
					selected: true
				},
				Option {
					text: qsTr("Accounts") + Retranslate.onLanguageChanged
					value: "accounts"
				},
				Option {
					text: qsTr("Printers") + Retranslate.onLanguageChanged
					value: "printers"
				}
			]

			onSelectedValueChanged: {
				if (selectedValue == "accounts") {
					generalContainer.visible = false;
					printersContainer.visible = false;
					accountsContainer.visible = true;
				}
				else if (selectedValue == "printers") {
					generalContainer.visible = false;
					accountsContainer.visible = false;
					printersContainer.visible = true;
				} 
				else {
					accountsContainer.visible = false;
					printersContainer.visible = false;
					generalContainer.visible = true;
				}
			}
		}

		ScrollView {
			id: generalContainer
			visible: true

			scrollViewProperties.scrollMode: ScrollMode.Vertical
			scrollViewProperties.pinchToZoomEnabled: false

			horizontalAlignment: HorizontalAlignment.Fill
			verticalAlignment: VerticalAlignment.Fill

			content: Container {
				horizontalAlignment: HorizontalAlignment.Fill

				Container {
					horizontalAlignment: HorizontalAlignment.Center

					layout: StackLayout {
					}
						
					layoutProperties: StackLayoutProperties {
					}

					Label {
						text: qsTr("Theme:") + Retranslate.onLanguageChanged

                        translationX: 10.0
                        
                        horizontalAlignment: HorizontalAlignment.Left
						verticalAlignment: VerticalAlignment.Center

                        textStyle {
							base: SystemDefaults.TextStyles.BodyText
                            fontWeight: FontWeight.Bold
                        	color: Color.create("#ff038ebc")
                        }
					}

                    ImageView {
                        imageSource: "asset:///images/divider.png"
                        horizontalAlignment: HorizontalAlignment.Fill
                        
                        translationY: -10.0
                    }

					Container {
						DropDown {
							id: themeDropDown
							objectName: "themeDropDown"

							title: qsTr("Choose a theme") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Fill

							layoutProperties: StackLayoutProperties {
							}

							Option {
								value: "bright"
								text: qsTr("Bright") + Retranslate.onLanguageChanged
							}
							Option {
								value: "dark"
								text: qsTr("Dark") + Retranslate.onLanguageChanged
							}

							onSelectedIndexChanged: {
								settingsModel.editGeneralSettingsItem("theme", selectedValue);
							}
						}

						TextArea {
							editable: false
							text: qsTr("Need to restart the application.") + Retranslate.onLanguageChanged

							verticalAlignment: VerticalAlignment.Center
							leftPadding: 20.0
							
							textStyle {
								base: SystemDefaults.TextStyles.BodyText
								fontStyle: FontStyle.Italic
							}
						}
					}

					Label {
						text: qsTr("Icon size:") + Retranslate.onLanguageChanged

                        translationX: 10.0
                        
                        horizontalAlignment: HorizontalAlignment.Left
						verticalAlignment: VerticalAlignment.Center

                        textStyle {
							base: SystemDefaults.TextStyles.BodyText
                            fontWeight: FontWeight.Bold
                        	color: Color.create("#ff038ebc")
                        }
					}

                    ImageView {
                        imageSource: "asset:///images/divider.png"
                        horizontalAlignment: HorizontalAlignment.Fill
                        
                        translationY: -10.0
                    }

					Container {
						TextArea {
							editable: false
							text: qsTr("Just pinch the screen to change the icon size.") + Retranslate.onLanguageChanged

							verticalAlignment: VerticalAlignment.Center
							leftPadding: 20.0
							
							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
					}

					Label {
						text: qsTr("BlackBerry Messenger link:") + Retranslate.onLanguageChanged

                        translationX: 10.0
                        
                        horizontalAlignment: HorizontalAlignment.Left
						verticalAlignment: VerticalAlignment.Center

                        textStyle {
							base: SystemDefaults.TextStyles.BodyText
                            fontWeight: FontWeight.Bold
                        	color: Color.create("#ff038ebc")
                        }
					}

                    ImageView {
                        imageSource: "asset:///images/divider.png"
                        horizontalAlignment: HorizontalAlignment.Fill
                        
                        translationY: -10.0
                    }

					Container {
						visible: settingsMainPage.bbmstatus == "unregistered"

						TextArea {
							editable: false
							text: qsTr("Connect PlayCloud to BlackBerry® Messenger ?") + Retranslate.onLanguageChanged

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
					
						Button {
							text: qsTr("Connect") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Center

							layoutProperties: StackLayoutProperties {
							}

							onClicked: {
								settingsMainPage.bbmstatus = "registering";
								playcloud.startBBMRegistrationProcess();
							}
						}
					}

					Container {
						visible: settingsMainPage.bbmstatus == "registering"

						TextArea {
							editable: false
							text: qsTr("PlayCloud connecting to BlackBerry® Messenger...") + Retranslate.onLanguageChanged

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}

						ActivityIndicator {
							running: true

							preferredWidth: 150.0
							preferredHeight: 150.0
				
							horizontalAlignment: HorizontalAlignment.Center

							layoutProperties: StackLayoutProperties {
							}
						}
					}

					Container {
						visible: settingsMainPage.bbmstatus == "error"

						TextArea {
							editable: false
							id: settingsBBMStatusMessage

							text: ""

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
					}			

					Container {
						visible: settingsMainPage.bbmstatus == "registered"

						TextArea {
							editable: false
							text: qsTr("Invite someone to use PlayCloud ?") + Retranslate.onLanguageChanged

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
					
						Button {
							text: qsTr("Invite") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Center

							layoutProperties: StackLayoutProperties {
							}

							onClicked: {
								playcloud.inviteToDownload();
							}
						}

						Container {
							horizontalAlignment: HorizontalAlignment.Fill
							
							layout: StackLayout {
								orientation: LayoutOrientation.LeftToRight
							}
							
							CheckBox {
								id: settingsBBMUpdateActivitiesCheckBox

								checked: false
								
								verticalAlignment: VerticalAlignment.Center

								onCheckedChanged: {
									settingsModel.editGeneralSettingsItem("bbmupdateactivities", checked);
								}
							}

							TextArea {
								editable: false
								text: qsTr("Update my BlackBerry Messenger activities") + Retranslate.onLanguageChanged

								verticalAlignment: VerticalAlignment.Center
								leftPadding: 20.0
								
								textStyle {
									base: SystemDefaults.TextStyles.BodyText
								}
							}
						}

		//				TextArea {
		//					editable: false
		//					text: qsTr("Permissions are defined in the BlackBerry® Settings menu") + Retranslate.onLanguageChanged
		//
		//					textStyle {
		//						base: SystemDefaults.TextStyles.BodyText
		//	                    fontStyle: FontStyle.Italic
		//					}
		//				}
					
					}

					Label {
						text: qsTr("Password protection:") + Retranslate.onLanguageChanged

                        translationX: 10.0
                        
                        horizontalAlignment: HorizontalAlignment.Left
						verticalAlignment: VerticalAlignment.Center

                        textStyle {
							base: SystemDefaults.TextStyles.BodyText
                            fontWeight: FontWeight.Bold
                        	color: Color.create("#ff038ebc")
                        }
					}

                    ImageView {
                        imageSource: "asset:///images/divider.png"
                        horizontalAlignment: HorizontalAlignment.Fill
                        
                        translationY: -10.0
                    }

					Container {
						visible: !playcloud.passwordDefined

						horizontalAlignment: HorizontalAlignment.Fill

						TextArea {
							editable: false
							text: qsTr("None password protection") + Retranslate.onLanguageChanged

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
					
						Button {
							text: qsTr("Define password") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Center

							layoutProperties: StackLayoutProperties {
							}

							onClicked: {
								passwordDialog.open();
							}
						}
					}

					Container {
						visible: playcloud.passwordDefined

						horizontalAlignment: HorizontalAlignment.Fill

						TextArea {
							editable: false
							text: qsTr("A password is defined") + Retranslate.onLanguageChanged

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
					
						Button {
							text: qsTr("Change password") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Center

							layoutProperties: StackLayoutProperties {
							}

							onClicked: {
								passwordDialog.open();
							}
						}
					}

					Label {
						text: qsTr("Network cache:") + Retranslate.onLanguageChanged

                        translationX: 10.0
                        
                        horizontalAlignment: HorizontalAlignment.Left
						verticalAlignment: VerticalAlignment.Center

                        textStyle {
							base: SystemDefaults.TextStyles.BodyText
                            fontWeight: FontWeight.Bold
                        	color: Color.create("#ff038ebc")
                        }
					}

                    ImageView {
                        imageSource: "asset:///images/divider.png"
                        horizontalAlignment: HorizontalAlignment.Fill
                        
                        translationY: -10.0
                    }


					Container {
						horizontalAlignment: HorizontalAlignment.Fill

						Container {
							horizontalAlignment: HorizontalAlignment.Fill

							preferredWidth: 1440

							layout: DockLayout {
							}

							Label {
								text: qsTr("Cache size (in MB)") + Retranslate.onLanguageChanged
								
								horizontalAlignment: HorizontalAlignment.Left
								verticalAlignment: VerticalAlignment.Center
								
								textStyle {
									base: SystemDefaults.TextStyles.BodyText
								}
							}
							
							Label {
								id: cacheSizeLabel
								
								horizontalAlignment: HorizontalAlignment.Right
								verticalAlignment: VerticalAlignment.Center
								
								textStyle {
									base: SystemDefaults.TextStyles.BodyText
								}
							}
						}
						
						ProgressIndicator {
							id: cacheSizeIndicator
							fromValue: 0
							toValue: settingsMainPage.maxcachesize
							state: ProgressIndicatorState.Pause
							
							horizontalAlignment: HorizontalAlignment.Fill

							value: settingsMainPage.cachesize
						}
						
						Slider {
							id: cacheSizeSlider
							fromValue: 10
							toValue: 200
							value: settingsMainPage.maxcachesize

							horizontalAlignment: HorizontalAlignment.Fill
							
							onImmediateValueChanged: {
								settingsMainPage.maxcachesize = immediateValue;
								updateCacheInfo();
							}
							
							onValueChanged: {
								settingsModel.editGeneralSettingsItem("cachesize", value * 1024 * 1024);
								playcloud.setMaximumCacheSize(value * 1024 * 1024);
								settingsMainPage.maxcachesize = playcloud.getMaximumCacheSize() / (1024 * 1024);
								settingsMainPage.cachesize = playcloud.getCacheSize() / (1024 * 1024);
								updateCacheInfo();
							}
						}
					
						Button {
							text: qsTr("Clear cache data") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Center

							layoutProperties: StackLayoutProperties {
							}

							onClicked: {
								playcloud.clearCache();
								settingsMainPage.cachesize = playcloud.getCacheSize() / (1024 * 1024);
								updateCacheInfo(settingsMainPage.maxcachesize);
							}
						}
					}    
				}
			}
		}

		Container {
			id: accountsContainer
			visible: false

			horizontalAlignment: HorizontalAlignment.Center

			layout: StackLayout {
			}
				
			layoutProperties: StackLayoutProperties {
			}

		
			ListView {
				id: settingsList
				
				attachedObjects: [
					PlayCloudSettings {
						id: settingsModel
					}
				]
				
				dataModel: settingsModel.getAccountsModel()

				listItemComponents: [
					ListItemComponent {
						SettingsItem {
						}
					}
				]
				
				onTriggered: {
					clearSelection();
					select(indexPath);

					// When an item is selected we push the recipe Page in the chosenItem file attribute.
					var chosenItem = dataModel.data(indexPath);

					pageSettingsCloudDefinition.source = "asset:///Settings/" + chosenItem.file;

					var page = pageSettingsCloudDefinition.createObject();
					
					page.json = chosenItem;
					page.index = indexPath;
					page.model = settingsModel;
					
					page.init();

					navigationPane.push(page);
				}

				function deleteAccountItem(indexPath) {
					settingsModel.deleteAccountItem(indexPath);
				}
			}
		}

		Container {
			id: printersContainer
			visible: false

			horizontalAlignment: HorizontalAlignment.Center

			layout: StackLayout {
			}
				
			layoutProperties: StackLayoutProperties {
			}

		
			ListView {
				id: printersList
				
				attachedObjects: [
					PlayCloudSettings {
						id: printersModel
					}
				]

				dataModel: printersModel.getPrintersModel()
				
				listItemComponents: [
					ListItemComponent {
						PrintersItem {
						}
					}
				]
				
				onTriggered: {
					clearSelection();
					select(indexPath);

					// When an item is selected we push the recipe Page in the chosenItem file attribute.
					var chosenItem = dataModel.data(indexPath);

					var page = pagePrinterCloudDefinition.createObject();
					
					page.json = chosenItem;
					page.index = indexPath;
					page.model = printersModel;
					
					page.init();

					navigationPane.push(page);
				}

				function testPrintersItem(indexPath, type) {
					playcloud.testPrintersItem(indexPath, type);
				}

				function deletePrintersItem(indexPath, image) {
					playcloud.deleteImagePrinter(image);
					printersModel.deletePrintersItem(indexPath);
				}
			}
		}
	}

//    paneProperties: NavigationPaneProperties {
//        backButton: ActionItem {
//            onTriggered: { 
//                console.log("Settings complete");
//                playcloud.reloadSettings();
//                navigationPane.pop(); 
//            }
//        }
//    }

    actions: [
        ActionItem { 
			id: actionAddPrinter
            title: qsTr("Add printer") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/dock/newprinter.png"

            onTriggered: {
				var page = pagePrinterCloudDefinition.createObject();
				
				page.json = null;
				page.index = null;
				page.model = printersModel;
				
				page.init();

				navigationPane.push(page);
            }
        },
        ActionItem { 
			id: actionAddAccount
            title: qsTr("Add account") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/dock/addaccount.png"

//            ActionBar.placement: ActionBarPlacement.OnBar
            ActionBar.placement: ActionBarPlacement.Signature

            onTriggered: {
				var page = pageNewAccountDefinition.createObject();
				
				page.model = printersModel;

				page.init();

				page.open();
            }
        },
        DeleteActionItem { 
            title: qsTr("Reset") + Retranslate.onLanguageChanged
            imageSource: "asset:///images/dock/reset.png"
           
            // When this action is selected, pop the current Page off
            // of the stack and delete it
            onTriggered: {
				settingsModel.reset();
            }
        }
    ]

	onCreationCompleted: {
		OrientationSupport.supportedDisplayOrientation = 
			SupportedDisplayOrientation.All;
			
        updateCacheInfo();

		playcloud.statusBBMRegistrationChanged.connect(settingsMainPage.onStatusBBMRegistrationChanged);

		playcloud.checkBBMRegistrationAccess(false);
	}
     
    function updateCacheInfo() {
        cacheSizeLabel.text = settingsMainPage.cachesize + " / " + settingsMainPage.maxcachesize.toFixed(0) + " " + qsTr("MB");
    }
    
	function onStatusBBMRegistrationChanged(status, updateactivities, message) {
		console.log("onStatusBBMRegistrationChanged");

		settingsMainPage.bbmstatus = status;
		settingsMainPage.bbmupdateactivities = updateactivities;
		settingsMainPage.bbmlabel = message;
	}
}

