import bb.cascades 1.3
import bb.cascades.pickers 1.0

import com.playcloud.settings 1.0

Page {
    id: printerPage

    property variant index
    property variant json
    property variant model

	attachedObjects: [
		FilePicker {
			id: printerPicker

			property string printerImageFile

			title: qsTr ("Printer image")
			mode: FilePickerMode.Picker
			type: FileType.Picture
			viewMode: ViewMode.GridView
			sortBy: FilePickerSortFlag.Default
			sortOrder: FilePickerSortOrder.Default

			onFileSelected: {
				printerImageFile = selectedFiles[0]

				printerImageFile = playcloud.prepareImagePrinter(printerImageFile);

				console.log("remove " + printerImage.imageSource);

				playcloud.deleteImagePrinter(printerImage.imageSource);

				console.log("to replace by " + printerImageFile);

		    	printerImage.imageSource = "file://" + printerImageFile;
		
				model.editPrintersItem(printerPage.index, "image", "file://" + printerImageFile);
			}
		}
	]

    ScrollView {
        scrollViewProperties.scrollMode: ScrollMode.Vertical

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Fill

	    content: Container {
			leftPadding: 15.0
			rightPadding: 15.0
			topPadding: 15.0
			bottomPadding: 15.0

			horizontalAlignment: HorizontalAlignment.Center

	        layout: StackLayout {
	        }
	        
	        layoutProperties: StackLayoutProperties {
	        }
	        
	        Container {
	            bottomMargin: 20.0
	
				horizontalAlignment: HorizontalAlignment.Fill

                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
	            
	            layoutProperties: StackLayoutProperties {
	            }

	            ImageView {
					id: printerImage
				
					property variant state: TouchEvent.Up

					preferredWidth: 240.0
					preferredHeight: 240.0
					
			        imageSource: "asset:///images/printers/default.png" 
			   
					scalingMethod: ScalingMethod.AspectFit
	                leftMargin: 20.0
	                topMargin: 10.0
	                rightMargin: 0.0
	                bottomMargin: 10.0

					onTouch: {
						if (event.isUp() && printerImage.state == TouchType.Down) {
							printerImage.state = TouchType.Up;
							printerPicker.open();
						}
						if (event.isDown())
							printerImage.state = TouchType.Down;
						else if (event.isCancel())
							printerImage.state = TouchType.Up;
					}
	            }

                Label {
	                text: qsTr("Printer") + Retranslate.onLanguageChanged
		            
	                rightMargin: 20.0

					horizontalAlignment: HorizontalAlignment.Fill
					verticalAlignment: VerticalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1.0
                    }

	                textStyle {
	                    base: SystemDefaults.TextStyles.BigText
	                    fontWeight: FontWeight.Bold
                        textAlign: TextAlign.Center
	                }
		        }
		    }
	
	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

	            layout: DockLayout {
	            }
	            
	            layoutProperties: StackLayoutProperties {
	            }
	            
	            Label {
	                text: qsTr("Enable") + Retranslate.onLanguageChanged

					verticalAlignment: VerticalAlignment.Center

                    textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }
	            }
		
		        ToggleButton {
		            id: toggleButton
		            
                    checked: printerPage.json.enable

					horizontalAlignment: HorizontalAlignment.Right
					verticalAlignment: VerticalAlignment.Center

                    onCheckedChanged: {
						if (printerPage.index)
	                        model.editPrintersItem(printerPage.index, "enable", checked);
                    }
                }
		    }
	
		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

		        layout: StackLayout {
		        }
		        
		        layoutProperties: StackLayoutProperties {
		        }
		
		        TextField {
		            id: host
		            text: printerPage.json.host
                    hintText: qsTr("Host") + Retranslate.onLanguageChanged
                    inputMode: TextFieldInputMode.Url
                    
                    horizontalAlignment: HorizontalAlignment.Fill

                    layoutProperties: StackLayoutProperties {
                    }
                    
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }

                    onTextChanged: {
						if (printerPage.index && text)
                        	model.editPrintersItem(printerPage.index, "host", text);
                    }
                }

		        TextField {
		            id: username
		            text: printerPage.json.username
                    hintText: qsTr("Username") + Retranslate.onLanguageChanged
                    inputMode: TextFieldInputMode.Url
                    
                    horizontalAlignment: HorizontalAlignment.Fill

                    layoutProperties: StackLayoutProperties {
                    }
                    
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }

                    onTextChanged: {
						if (printerPage.index)
                        	model.editPrintersItem(printerPage.index, "username", text);
                    }
                }

		        TextField {
		            id: password
		            text: printerPage.json.password
                    hintText: qsTr("Password") + Retranslate.onLanguageChanged
                    inputMode: TextFieldInputMode.Password
                    
					horizontalAlignment: HorizontalAlignment.Fill

                    layoutProperties: StackLayoutProperties {
                    }
                    
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }

                    onTextChanged: {
						if (printerPage.index)
                        	model.editPrintersItem(printerPage.index, "password", text);
                    }
                }
			}	

		    Divider {
		    }

			Container {
				horizontalAlignment: HorizontalAlignment.Fill

				layout: StackLayout {
				}
				
				layoutProperties: StackLayoutProperties {
				}
				
				Label {
					text: qsTr("Name") + Retranslate.onLanguageChanged

					horizontalAlignment: HorizontalAlignment.Left

	                translationX: 10.0

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						fontWeight: FontWeight.Bold
                   		color: Color.create("#ff038ebc")
					}
				}

				ImageView {
					imageSource: "asset:///images/divider.png"
					horizontalAlignment: HorizontalAlignment.Fill

                    translationY: -10.0
				}

				TextField {
					id: printerName

		            text: printerPage.json.title
					leftPadding: 10.0
					rightPadding: 10.0
					
					horizontalAlignment: HorizontalAlignment.Fill
					clearButtonVisible: false

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						textAlign: TextAlign.Left
					}

                    onTextChanged: {
						if (printerPage.index && text)
                        	model.editPrintersItem(printerPage.index, "title", text);
                    }
				}
				
				Label {
					text: qsTr("Description") + Retranslate.onLanguageChanged

	                translationX: 10.0

					horizontalAlignment: HorizontalAlignment.Left

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						fontWeight: FontWeight.Bold
                   		color: Color.create("#ff038ebc")
					}
				}

				ImageView {
					imageSource: "asset:///images/divider.png"
					horizontalAlignment: HorizontalAlignment.Fill

                    translationY: -10.0
				}

				TextField {
					id: printerDescription

		            text: printerPage.json.description
					leftPadding: 10.0
					rightPadding: 10.0
					
					horizontalAlignment: HorizontalAlignment.Fill
					clearButtonVisible: false

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						textAlign: TextAlign.Left
					}

                    onTextChanged: {
						if (printerPage.index)
                        	model.editPrintersItem(printerPage.index, "description", text);
                    }
				}
				
				Label {
					text: qsTr("Location") + Retranslate.onLanguageChanged

	                translationX: 10.0

					horizontalAlignment: HorizontalAlignment.Left

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						fontWeight: FontWeight.Bold
                   		color: Color.create("#ff038ebc")
					}
				}

				ImageView {
					imageSource: "asset:///images/divider.png"
					horizontalAlignment: HorizontalAlignment.Fill

                    translationY: -10.0
				}

				TextField {
					id: printerLocation

		            text: printerPage.json.location
					leftPadding: 10.0
					rightPadding: 10.0
					
					horizontalAlignment: HorizontalAlignment.Fill
					clearButtonVisible: false

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						textAlign: TextAlign.Left
					}

                    onTextChanged: {
						if (printerPage.index)
                        	model.editPrintersItem(printerPage.index, "location", text);
                    }
				}
			}

		    Divider {
		    }

			Container {
				horizontalAlignment: HorizontalAlignment.Fill

				layout: StackLayout {
				}
				
				layoutProperties: StackLayoutProperties {
				}

				Label {
					text: qsTr("Printer info") + Retranslate.onLanguageChanged

	                translationX: 10.0

					horizontalAlignment: HorizontalAlignment.Left

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						fontWeight: FontWeight.Bold
                   		color: Color.create("#ff038ebc")
					}
				}

				ImageView {
					imageSource: "asset:///images/divider.png"
					horizontalAlignment: HorizontalAlignment.Fill

                    translationY: -10.0
				}

				Container {
					id: printerInfoError
					visible: false

					horizontalAlignment: HorizontalAlignment.Fill

					layout: StackLayout {
					}
					
					layoutProperties: StackLayoutProperties {
					}

					Label {
						text: qsTr("Printer connection failure !") + Retranslate.onLanguageChanged

						horizontalAlignment: HorizontalAlignment.Left

						layoutProperties: StackLayoutProperties {
						}

						textStyle {
							base: SystemDefaults.TextStyles.BodyText
							fontWeight: FontWeight.Bold
						}
					}
				}

				Container {
					id: printerInfoDetails
					visible: false

					horizontalAlignment: HorizontalAlignment.Fill

					layout: StackLayout {
					}
					
					layoutProperties: StackLayoutProperties {
					}

					Container {
						horizontalAlignment: HorizontalAlignment.Fill

						layout: DockLayout {
						}
					
						Label {
							text: qsTr("State:") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Left
							verticalAlignment: VerticalAlignment.Center

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
		
						Label {
							id: printerStateLabel
							text: "-"

							horizontalAlignment: HorizontalAlignment.Right
							verticalAlignment: VerticalAlignment.Center

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
								fontStyle: FontStyle.Italic
							}
						}
					}

					Container {
						horizontalAlignment: HorizontalAlignment.Fill

						layout: DockLayout {
						}
					
						Label {
							text: qsTr("Accept job:") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Left
							verticalAlignment: VerticalAlignment.Center

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
		
						Label {
							id: acceptJobLabel
							text: "-"

							horizontalAlignment: HorizontalAlignment.Right
							verticalAlignment: VerticalAlignment.Center

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
								fontStyle: FontStyle.Italic
							}
						}
					}

					Container {
						horizontalAlignment: HorizontalAlignment.Fill

						layout: StackLayout {
						}
					
						layoutProperties: StackLayoutProperties {
						}
		        
						Label {
							text: qsTr("Document format supported:") + Retranslate.onLanguageChanged

							horizontalAlignment: HorizontalAlignment.Left

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
		
						TextArea {
							id: acceptFormatLabel
							editable: false
							text: "-"

							horizontalAlignment: HorizontalAlignment.Left

							textStyle {
								base: SystemDefaults.TextStyles.BodyText
								fontStyle: FontStyle.Italic
							}
						}
					}
				}
			}				

		    Divider {
		    }

			Container {
				horizontalAlignment: HorizontalAlignment.Fill

				layout: StackLayout {
				}
				
				layoutProperties: StackLayoutProperties {
				}
				
				Label {
					text: qsTr("Test connection, and load printer settings") + Retranslate.onLanguageChanged

					horizontalAlignment: HorizontalAlignment.Left

					layoutProperties: StackLayoutProperties {
					}

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
					}
				}

		        Button {
		            id: buttonLoadDefault
		            text: qsTr("Check and load settings") + Retranslate.onLanguageChanged

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

                    onClicked: loadDefaultPrinterSettings()
                }


				Container {
					id: progressInfo

					visible: false
					horizontalAlignment: HorizontalAlignment.Fill

					leftPadding: 20.0
					bottomPadding: 10.0

					layout: StackLayout {
						orientation: LayoutOrientation.LeftToRight
					}

					ActivityIndicator {
						preferredWidth: 96.0
						preferredHeight: 96.0
			
						verticalAlignment: VerticalAlignment.Center

						layoutProperties: StackLayoutProperties {
						}
					}

					Label {
						text: qsTr("Loading...") + Retranslate.onLanguageChanged

						horizontalAlignment: HorizontalAlignment.Left
						verticalAlignment: VerticalAlignment.Center

						layoutProperties: StackLayoutProperties {
						}

						textStyle {
							base: SystemDefaults.TextStyles.BodyText
						}
					}
				}

				Container {
					horizontalAlignment: HorizontalAlignment.Fill
					verticalAlignment: VerticalAlignment.Bottom

					leftPadding: 20.0
					bottomPadding: 10.0

					layout: StackLayout {
						orientation: LayoutOrientation.LeftToRight
					}

					CheckBox {
						id: loadCheckBox

						checked: false
						
						verticalAlignment: VerticalAlignment.Center
					}

					TextArea {
						editable: false
						text: qsTr("Replace my current settings") + Retranslate.onLanguageChanged

						verticalAlignment: VerticalAlignment.Center
						leftPadding: 20.0
						
						textStyle {
							base: SystemDefaults.TextStyles.BodyText
						}
					}
				}
			}

	    }
    }

	onCreationCompleted: {
		OrientationSupport.supportedDisplayOrientation = 
			SupportedDisplayOrientation.All;
	}


    actions: [
//        ActionItem { 
//            title: "Back"
//            ActionBar.placement: ActionBarPlacement.OnBar
//           
//            // When this action is selected, pop the current Page off
//            // of the stack and delete it
//            onTriggered: {
//                navigationPane.popAndDelete()
//            }
//        }
    ] // end of actions list


	function init() {
		console.log("Printer page init");

		if (!printerPage.index) {
			console.log("Create printer");

			printerInfoDetails.visible = false;

			printerPage.model.getPrintersModel().itemAdded.connect(printerPage.onPrinterAdded);
			printerPage.model.addPrintersItem();

			printerName.text = qsTr("New printer");

			loadCheckBox.checked = true;
		}
		else {
			if (printerPage.json && printerPage.json.image) {
		    	printerImage.imageSource = printerPage.json.image;
			}

			printerInfoDetails.visible = true;

			playcloud.printerError.connect(printerPage.onPrinterError);
			playcloud.printerStatusChanged.connect(printerPage.onPrinterStatusChanged);

			playcloud.getPrinterStatus(printerPage.index);
		}
	}

	function onPrinterAdded(indexPath) {
		console.log("New printer item created");

		printerPage.model.getPrintersModel().itemAdded.disconnect(printerPage.onPrinterAdded);

		printerPage.index = indexPath;

		model.editPrintersItem(printerPage.index, "image", printerImage.imageSource);
	}
    
	function loadDefaultPrinterSettings() {
		console.log("button load default printer settings");

		progressInfo.visible = true;
		printerInfoError.visible = false;
		printerInfoDetails.visible = false;

		playcloud.printerError.connect(printerPage.onPrinterError);
        playcloud.printerInfoChanged.connect(printerPage.onDefaultPrinterSettingsLoaded);
		playcloud.printerStatusChanged.connect(printerPage.onPrinterStatusChanged);

		playcloud.loadDefaultPrinterSettings(host.text, username.text, password.text);
	}

	function onPrinterError() {
		console.log("QML onPrinterError");

		progressInfo.visible = false;
		printerInfoError.visible = true;
		printerInfoDetails.visible = false;
	}

	function onDefaultPrinterSettingsLoaded(name, description, location) {
		console.log("QML onDefaultPrinterSettingsLoaded");

		progressInfo.visible = false;
		printerInfoError.visible = false;
		printerInfoDetails.visible = true;

		if (loadCheckBox.checked) {
			printerName.text = name;
			printerDescription.text = description;
			printerLocation.text = location;

			loadCheckBox.checked = false;
		}
	}

	function onPrinterStatusChanged(state, accept, format, uptime) {
		console.log("QML onPrinterStatusChanged");

		progressInfo.visible = false;
		printerStateLabel.text = state;
		acceptJobLabel.text = accept;
		acceptFormatLabel.text = format;
//		uptimeLabel.text = uptime;
	}
} // end of Page
	
