import bb.cascades 1.3

import LocaleHandler 1.0
import com.playcloud.settings 1.0

Page {
    id: settingsPage

    property string status: "unregistered"
    
    property variant index
    property variant json
    property variant model

	property string code

	attachedObjects: [
		ComponentDefinition {
			id: pageGoogleDriveRegisterDefinition
			source: "asset:///Settings/GoogleDriveRegister.qml"
		},
		LocaleHandler {
			onLanguageChanged: {
				settingsPage.updateRegistrationStatus();
			}
		}
	]

    ScrollView {
        scrollViewProperties.scrollMode: ScrollMode.Vertical

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Fill

	    content: Container {
			leftPadding: 15.0
			rightPadding: 15.0
			topPadding: 15.0
			bottomPadding: 15.0

			horizontalAlignment: HorizontalAlignment.Center

	        layout: StackLayout {
	        }
	        
	        layoutProperties: StackLayoutProperties {
	        }
	        
	        Container {
	            bottomMargin: 20.0
	
				horizontalAlignment: HorizontalAlignment.Fill

                layout: StackLayout {
                    orientation: LayoutOrientation.LeftToRight
                }
	            
	            layoutProperties: StackLayoutProperties {
	            }
	
	            ImageView {
			        imageSource: "asset:///images/settings/googledriveheader.png" 
			   
	                scalingMethod: ScalingMethod.None
	                leftMargin: 20.0
	                topMargin: 10.0
	                rightMargin: 0.0
	                bottomMargin: 10.0
	            }
		
		        Label {
		            text: "Google Drive"
		            
					rightMargin: 20.0

					horizontalAlignment: HorizontalAlignment.Fill
					verticalAlignment: VerticalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                        spaceQuota: 1.0
                    }

                    textStyle {
	                    base: SystemDefaults.TextStyles.BigText
	                    fontWeight: FontWeight.Bold
                        textAlign: TextAlign.Center
	                }
		        }
		    }
	
	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

	            layout: DockLayout {
	            }
	            
	            layoutProperties: StackLayoutProperties {
	            }
	            
	            Label {
	                text: qsTr("Enable") + Retranslate.onLanguageChanged

					verticalAlignment: VerticalAlignment.Center

                    textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }
	            }
		
		        ToggleButton {
		            id: toggleButton
		            
                    checked: settingsPage.json.ui.enable
                    enabled: settingsPage.json.account.registered

					horizontalAlignment: HorizontalAlignment.Right
					verticalAlignment: VerticalAlignment.Center

                    onCheckedChanged: {
                        model.editAccountUISettingsItem(settingsPage.index, "enable", checked);
                    }
                }
		    }
	
		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

		        layout: StackLayout {
		        }
		        
		        layoutProperties: StackLayoutProperties {
		        }
		        
		        Button {
		            id: buttonRegister
		            text: ""

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

                    onClicked: continueRegistrationProcess()
                }

		        Label {
		            id: registerStatus
		            objectName: "registerStatus"
		            
		            text: ""

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

                    textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                    fontStyle: FontStyle.Italic
	                }
		        }
		    }
				
		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

		        layout: StackLayout {
		        }
		        
		        layoutProperties: StackLayoutProperties {
		        }
		
		        Label {
		            text: qsTr("Title") + Retranslate.onLanguageChanged
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }
		        }
	
		        TextField {
		            id: title
		            text: settingsPage.json.title
                    hintText: qsTr("Enter the title of view") + Retranslate.onLanguageChanged
                    inputMode: TextFieldInputMode.Url
                    
                    horizontalAlignment: HorizontalAlignment.Fill

                    layoutProperties: StackLayoutProperties {
                    }
                    
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }

                    onTextChanged: {
                        model.editSettingsItem(settingsPage.index, "title", text);
                    }
                }
			}
	
		    Divider {
		    }
	
	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

		        layout: StackLayout {
		        }
		        
		        layoutProperties: StackLayoutProperties {
		        }
		
		        Label {
		            text: qsTr("Display mode") + Retranslate.onLanguageChanged
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }
		        }
	
		        DropDown {
		            id: dropdownMode
	                title: qsTr("Mode by default") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.ui.display

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

                    Option {
	                    value: 1
	                    text: qsTr("Categories") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("Icons") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("List") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountUISettingsItem(settingsPage.index, "display", selectedIndex);
                    }
		        }
		    }
		    
		    Divider {
		    }
	
	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

		        layout: StackLayout {
		        }
		        
		        layoutProperties: StackLayoutProperties {
		        }
		
		        Label {
		            text: qsTr("Order settings") + Retranslate.onLanguageChanged
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }
		        }
	
		        DropDown {
		            id: dropdownOrder
	                title: qsTr("Order by default") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.ui.order

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 1
	                    text: qsTr("Name") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("Date") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("Size") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 4
	                    text: qsTr("Type") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountUISettingsItem(settingsPage.index, "order", selectedIndex);
                    }
		        }
		    }
		    
		    Divider {
		    }
	
	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

		        layout: StackLayout {
		        }
		        
		        layoutProperties: StackLayoutProperties {
		        }
		
		        Label {
		            text: qsTr("Open mode") + Retranslate.onLanguageChanged
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }
		        }
	
		        DropDown {
		            id: dropdownDirectory
	                title: qsTr("Open a directory") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.ui.opendirectory

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 1
	                    text: qsTr("Open at first tap") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("Open at second tap") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("Don't open") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountUISettingsItem(settingsPage.index, "opendirectory", selectedIndex);
                    }
		        }
	
		        DropDown {
		            id: dropdownFile
	                title: qsTr("Open a file") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.ui.openfile

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 1
	                    text: qsTr("Open at first tap") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("Open at second tap") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("Don't open") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountUISettingsItem(settingsPage.index, "openfile", selectedIndex);
                    }
		        }

   				Container {
   					horizontalAlignment: HorizontalAlignment.Fill
   					
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    
                    CheckBox {
                    	checked: settingsPage.json.ui.openwithdefault
	                    
						verticalAlignment: VerticalAlignment.Center
	                    
	                    onCheckedChanged: {
	                        model.editAccountUISettingsItem(settingsPage.index, "openwithdefault", checked);
	                    }
	                }

   					Label {
	                    text: qsTr("Open with the default application") + Retranslate.onLanguageChanged

   						verticalAlignment: VerticalAlignment.Center
                        leftPadding: 20.0
                        
                        textStyle {
   							base: SystemDefaults.TextStyles.BodyText
   						}
   					}
			    }
		    }
	
		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

		        layout: StackLayout {
		        }
		        
		        layoutProperties: StackLayoutProperties {
		        }
		
		        Label {
		            text: qsTr("Load thumbnails") + Retranslate.onLanguageChanged
	                textStyle {
	                    base: SystemDefaults.TextStyles.BodyText
	                }
		        }
	
		        DropDown {
		            id: dropdownThumb
                    selectedIndex: settingsPage.json.ui.thumbnail

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 1
	                    text: qsTr("Always") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("Never") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("On file selection") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 4
	                    text: qsTr("Only on WiFi network") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountUISettingsItem(settingsPage.index, "thumbnail", selectedIndex);
                    }
		        }
		    }
		    
		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

	            layout: StackLayout {
	            }
	            
				Container {
					horizontalAlignment: HorizontalAlignment.Fill

					layout: DockLayout {
					}
					
					Label {
						text: qsTr("Password protection") + Retranslate.onLanguageChanged

						verticalAlignment: VerticalAlignment.Center

						textStyle {
							base: SystemDefaults.TextStyles.BodyText
						}
					}
			
					ToggleButton {
						checked: settingsPage.json.ui.locked

						horizontalAlignment: HorizontalAlignment.Right
						verticalAlignment: VerticalAlignment.Center

						onCheckedChanged: {
							model.editAccountUISettingsItem(settingsPage.index, "locked", checked);
						}
					}
				}

		        TextArea {
					editable: false
		            text: qsTr(
						"Don't forget to define a password."
						) + Retranslate.onLanguageChanged

	                textStyle {
	                    base: SystemDefaults.TextStyles.SubtitleText
						fontStyle: FontStyle.Italic
	                }
		        }
			}

		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

	            layout: StackLayout {
	            }
	            
				Container {
					horizontalAlignment: HorizontalAlignment.Fill

					layout: DockLayout {
					}
					
					Label {
						text: qsTr("Auto connect") + Retranslate.onLanguageChanged

						verticalAlignment: VerticalAlignment.Center

						textStyle {
							base: SystemDefaults.TextStyles.BodyText
						}
					}
			
					ToggleButton {
						checked: settingsPage.json.ui.autoconnect

						horizontalAlignment: HorizontalAlignment.Right
						verticalAlignment: VerticalAlignment.Center

						onCheckedChanged: {
							model.editAccountUISettingsItem(settingsPage.index, "autoconnect", checked);
						}
					}
				}

		        DropDown {
		            id: networkDropdown
	                title: qsTr("Use on network") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.ui.network

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 1
	                    text: qsTr("WiFi & Cellular") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("WiFi") + Retranslate.onLanguageChanged
	                }
					Option {
						value: 3
						text: qsTr("Ignore") + Retranslate.onLanguageChanged
					}

                    onSelectedIndexChanged: {
                        model.editAccountUISettingsItem(settingsPage.index, "network", selectedIndex);
                    }
		        }
		        
   				Container {
   					horizontalAlignment: HorizontalAlignment.Fill
   					
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    
                    CheckBox {
                    	checked: settingsPage.json.ui.roaming
	                    enabled: networkDropdown.selectedIndex == 0
	                    
						verticalAlignment: VerticalAlignment.Center
	                    
	                    onCheckedChanged: {
	                        model.editAccountUISettingsItem(settingsPage.index, "roaming", checked);
	                    }
	                }

   					Label {
	                    text: qsTr("Permit to use roaming if enabled") + Retranslate.onLanguageChanged

   						verticalAlignment: VerticalAlignment.Center
                        leftPadding: 20.0
                        
                        textStyle {
   							base: SystemDefaults.TextStyles.BodyText
   						}
   					}
			    }
            }

			Divider {
			}

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

	            layout: StackLayout {
	            }
	            
		        DropDown {
		            id: sslversionDropdown
	                title: qsTr("SSL version") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.ssl.version

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 1
	                    text: qsTr("Default SSL version") + Retranslate.onLanguageChanged
						description: qsTr("Use the BlackBerry default behavior") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("SSLv2") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("SSLv3") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 4
	                    text: qsTr("SSLv2 / SSLv3") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 5
	                    text: qsTr("TLSv1.0") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 6
	                    text: qsTr("TLSv1.1") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 7
	                    text: qsTr("TLSv1.2") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountSSLSettingsItem(settingsPage.index, "version", selectedIndex);
                    }
		        }
		        
   				Container {
   					horizontalAlignment: HorizontalAlignment.Fill
   					
                    layout: StackLayout {
                        orientation: LayoutOrientation.LeftToRight
                    }
                    
                    CheckBox {
                    	checked: settingsPage.json.ssl.checkcertificate
	                    
						verticalAlignment: VerticalAlignment.Center
	                    
	                    onCheckedChanged: {
	                        model.editAccountSSLSettingsItem(settingsPage.index, "checkcertificate", checked);
	                    }
	                }

   					Label {
	                    text: qsTr("Check SSL certificate") + Retranslate.onLanguageChanged

   						verticalAlignment: VerticalAlignment.Center
                        leftPadding: 20.0
                        
                        textStyle {
   							base: SystemDefaults.TextStyles.BodyText
   						}
   					}
			    }
			}

		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

	            layout: StackLayout {
	            }
	            
				Label {
					text: qsTr("Documents import") + Retranslate.onLanguageChanged

					verticalAlignment: VerticalAlignment.Center

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
					}
				}

				Container {
					horizontalAlignment: HorizontalAlignment.Fill

					layout: DockLayout {
					}
					
					Label {
						text: qsTr("Convert to Google Doc") + Retranslate.onLanguageChanged

						verticalAlignment: VerticalAlignment.Center

						textStyle {
							base: SystemDefaults.TextStyles.BodyText
						}
					}
			
					ToggleButton {
						checked: settingsPage.json.account.convertImport

						horizontalAlignment: HorizontalAlignment.Right
						verticalAlignment: VerticalAlignment.Center

						onCheckedChanged: {
                        	model.editAccountSettingsItem(settingsPage.index, "convertImport", checked);
						}
					}
				}
			}

		    Divider {
		    }

	        Container {
				horizontalAlignment: HorizontalAlignment.Fill

	            layout: StackLayout {
	            }
	            
				Label {
					text: qsTr("Export Google Doc") + Retranslate.onLanguageChanged

					verticalAlignment: VerticalAlignment.Center

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
					}
				}

		        DropDown {
		            id: convertDocuments
	                title: qsTr("Documents") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.account.convertDocuments

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 0
	                    text: qsTr("MS Word document") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 1
	                    text: qsTr("Open Office doc") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("HTML") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("Plain text") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 4
	                    text: qsTr("Rich text") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 5
	                    text: qsTr("PDF") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountSettingsItem(settingsPage.index, "convertDocuments", selectedIndex);
                    }
		        }

		        DropDown {
		            id: convertSpreadsheets
	                title: qsTr("Spreadsheets") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.account.convertSpreadsheets

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 0
	                    text: qsTr("MS Excel") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 1
	                    text: qsTr("Open Office sheet") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("PDF") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountSettingsItem(settingsPage.index, "convertSpreadsheets", selectedIndex);
                    }
		        }

		        DropDown {
		            id: convertDrawings
	                title: qsTr("Drawings") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.account.convertDrawings

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 0
	                    text: qsTr("JPEG") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 1
	                    text: qsTr("PNG") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 2
	                    text: qsTr("SVG") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 3
	                    text: qsTr("PDF") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountSettingsItem(settingsPage.index, "convertDrawings", selectedIndex);
                    }
		        }

		        DropDown {
		            id: convertPresentations
	                title: qsTr("Presentations") + Retranslate.onLanguageChanged
                    selectedIndex: settingsPage.json.account.convertPresentations

					horizontalAlignment: HorizontalAlignment.Center

                    layoutProperties: StackLayoutProperties {
                    }

	                Option {
	                    value: 0
	                    text: qsTr("MS PowerPoint") + Retranslate.onLanguageChanged
	                }
	                Option {
	                    value: 1
	                    text: qsTr("PDF") + Retranslate.onLanguageChanged
	                }

                    onSelectedIndexChanged: {
                        model.editAccountSettingsItem(settingsPage.index, "convertPresentations", selectedIndex);
                    }
		        }
			}
	    }
    }

	onCreationCompleted: {
		OrientationSupport.supportedDisplayOrientation = 
			SupportedDisplayOrientation.All;
	}
     
    actions: [
//        ActionItem { 
//            title: "Back"
//            ActionBar.placement: ActionBarPlacement.OnBar
//           
//            // When this action is selected, pop the current Page off
//            // of the stack and delete it
//            onTriggered: {
//                navigationPane.popAndDelete()
//            }
//        }
    ] // end of actions list


    function init() {
        console.log("init registration status");

        if (settingsPage.json.account.registered)
	        settingsPage.status = "registered";
	    else
	        settingsPage.status = "unregistered";
	    	    
	    updateRegistrationStatus();
    }
    
        
    function continueRegistrationProcess() {
        console.log("button clicked : " + settingsPage.status);

        // State machine
        switch (settingsPage.status) {
        case "unregistered":
        case "unregistered_error":
        case "ticketing":
            settingsPage.status = "ticketing";
            playcloud.requestGoogleDriveRegistration();
            playcloud.statusGoogleDriveRegistrationChanged.connect(settingsPage.onStatusChanged);
            break;
            
		case "connect":
            settingsPage.status = "connecting";
            playcloud.accessGoogleDriveToken(settingsPage.code);
            playcloud.statusGoogleDriveRegistrationChanged.connect(settingsPage.onStatusChanged);
			break;
                            
        case "registered":
        case "registered_error":
            settingsPage.status = "unregistered";
            model.editAccountSettingsItem(settingsPage.index, "registered", false);
            model.editAccountSettingsItem(settingsPage.index, "accessToken", "");
            model.editAccountSettingsItem(settingsPage.index, "refreshToken", "");
            break;
        }
        
        // Update the UI
        updateRegistrationStatus();
	}


    function updateRegistrationStatus() {
        console.log("update status : " + settingsPage.status);

        switch (settingsPage.status) {
        case "unregistered":
            buttonRegister.text = qsTr("Register");
            registerStatus.text = qsTr("Not registered");
            toggleButton.checked = false;
            toggleButton.enabled = false;
            break;

        case "unregistered_error":
            buttonRegister.text = qsTr("Register");
            registerStatus.text = qsTr("Not registered. Connection failure, check your connection !");
            break;
            
        case "ticketing":
            registerStatus.text = qsTr("Registration processing...");
            break;
            
        case "connect":
        case "connect_error":
            buttonRegister.text = qsTr("Connect");
            registerStatus.text = qsTr("Now connect PlayCloud");
            break;

        case "connecting":
            registerStatus.text = qsTr("Connecting...");
            break;
            
        case "registered":
        case "registered_error":
            buttonRegister.text = qsTr("Unregister");
            registerStatus.text = qsTr("You are registered");
            toggleButton.enabled = true;
            break;
        }
	}


    function onStatusChanged(status, code, accessToken, refreshToken) {
        console.log("Status changed from C++ - new status:" + status);

		if (status == settingsPage.status)
			return;

		if (status == "connect") {
			settingsPage.code = code;

			navigationPane.pop();
		}
		else if (status == "registered") {
			model.editAccountSettingsItem(settingsPage.index, "accessToken", accessToken);
			model.editAccountSettingsItem(settingsPage.index, "refreshToken", refreshToken);
			model.editAccountSettingsItem(settingsPage.index, "registered", true);
		}
		else if (status == "unregistered_error") {
			navigationPane.pop();
		}

        settingsPage.status = status;
        
        updateRegistrationStatus();
    }
} // end of Page
