import bb.cascades 1.3
import "../Items"

Page {
	id: sharePage
	objectName: "sharePage"

    property alias activity: dataLoadIndicator.running

    property alias showpermissions: permissionsContainer.visible
    property alias showusers: usersContainer.visible
	property alias showbuttons: buttonsContainer.visible
    property alias showerror: errorContainer.visible

	property alias access: sharesAccess.selectedIndex
	property alias edit: sharesEdit.checked
	property alias comment: sharesComment.checked

	property bool actionSave: true
	property bool usersLoading: false

	property int error: 0

	signal permissionsChanged()
	signal sendSharedLink()
	signal actionContactClicked(string action, variant indexPath)

	attachedObjects: [
		GroupDataModel {
			id: groupDataModel 
			objectName: "groupDataModel"

			sortingKeys: ["name"]

			grouping: ItemGrouping.None
		}
	]

    titleBar: TitleBar {
        title: qsTr("Share with...") + Retranslate.onLanguageChanged
    }
	
    ScrollView {
        scrollViewProperties.scrollMode: ScrollMode.Vertical
        scrollViewProperties.pinchToZoomEnabled: false
	
		horizontalAlignment: HorizontalAlignment.Center
		verticalAlignment: VerticalAlignment.Fill
			
		content: Container {
			leftPadding: 15.0
			rightPadding: 15.0
			topPadding: 15.0
			bottomPadding: 15.0

			horizontalAlignment: HorizontalAlignment.Fill
	
	        layout: StackLayout {
	        }
	        
	        layoutProperties: StackLayoutProperties {
	            spaceQuota: 1
	        }
	        
			Container {
				bottomMargin: 20.0
				preferredWidth: 1440
		
				horizontalAlignment: HorizontalAlignment.Fill

				layout: StackLayout {
					orientation: LayoutOrientation.LeftToRight
				}
					
				layoutProperties: StackLayoutProperties {
				}
		
				ImageView {
					preferredWidth: 120.0
					preferredHeight: 120.0
					minWidth: 120.0
					minHeight: 120.0
						
					horizontalAlignment: HorizontalAlignment.Center
					verticalAlignment: VerticalAlignment.Center
			
					// The image is bound to the data in models/recipemodel.xml image attribute.
					imageSource: itemobject.icon
					scalingMethod: ScalingMethod.AspectFit
					
					layoutProperties: StackLayoutProperties {
					}
						
					leftMargin: 10.0
					rightMargin: 10.0
				}
			
				Label {
					text: itemobject.name
					
					horizontalAlignment: HorizontalAlignment.Center
					verticalAlignment: VerticalAlignment.Center

					textStyle {
						base: SystemDefaults.TextStyles.BodyText
						fontWeight: FontWeight.Bold
					}
				}
			}

			SegmentedControl {
				objectName: "segmentedControl"

				horizontalAlignment: HorizontalAlignment.Center

				options: [
					Option {
						text: qsTr("Permissions") + Retranslate.onLanguageChanged
						value: "permissions"
						selected: true
					},
					Option {
						id: segmentUsers
						text: qsTr("Users") + Retranslate.onLanguageChanged
						value: "users"
						enabled: usersContainer.visible || (permissionsContainer.visible && sharePage.actionSave)
					}
				]

				onSelectedValueChanged: {
					permissionsContainer.visible = false;
					buttonsContainer.visible = false;
					usersContainer.visible = false;
					errorContainer.visible = false;

					dataLoadIndicator.running = true;
				}
			}

            Container {
	            preferredWidth: 1440
                horizontalAlignment: HorizontalAlignment.Center

				layout: DockLayout {
				}

                ActivityIndicator {
					id: dataLoadIndicator
					preferredWidth: 400
					preferredHeight: 400
					horizontalAlignment: HorizontalAlignment.Center
					verticalAlignment: VerticalAlignment.Top
	                running: true
	            }
	
				Container {
					id: permissionsContainer
					objectName: "permissionsContainer"
					visible: false
		
					horizontalAlignment: HorizontalAlignment.Fill
		
					layout: StackLayout {
					}
						
					layoutProperties: StackLayoutProperties {
					}
						
					RadioGroup {
						id: sharesAccess

						bottomMargin: 20.0
						
						Option {
							text: qsTr("Private")
							description: qsTr("Only people granted permission")
							value: "private"
						}
						Option {
							text: qsTr("Anyone with the link")
							description: qsTr("Anyone with the link can access")
							value: "anyonewithlink"
						}
						Option {
							text: qsTr("Public on the web")
							description: qsTr("Anyone on the Internet can access")
							value: "anyone"
						}

						onSelectedIndexChanged: {
							onPermissionsChanged();
						}
					}
						

					Container {
						visible: (sharesAccess.selectedValue == "anyone" || sharesAccess.selectedValue == "anyonewithlink")
						
						horizontalAlignment: HorizontalAlignment.Fill
						
						Divider {
							horizontalAlignment: HorizontalAlignment.Fill
						}
					
						Container {
							horizontalAlignment: HorizontalAlignment.Fill
				
							bottomMargin: 15.0

							layout: StackLayout {
								orientation: LayoutOrientation.LeftToRight
							}

							CheckBox {
								id: sharesEdit
								verticalAlignment: VerticalAlignment.Center

								onCheckedChanged: {
									onPermissionsChanged();
								}
							}
				
							Label {
								text: qsTr("Allow to edit") + Retranslate.onLanguageChanged
				
								verticalAlignment: VerticalAlignment.Center

								textStyle {
									base: SystemDefaults.TextStyles.BodyText
								}
							}
						}
					
						Container {
							horizontalAlignment: HorizontalAlignment.Fill
				
							bottomMargin: 25.0

							layout: StackLayout {
								orientation: LayoutOrientation.LeftToRight
							}

							CheckBox {
								id: sharesComment
								verticalAlignment: VerticalAlignment.Center

								onCheckedChanged: {
									onPermissionsChanged();
								}
							}
				
							Label {
								text: qsTr("Allow to comment") + Retranslate.onLanguageChanged
				
								verticalAlignment: VerticalAlignment.Center

								textStyle {
									base: SystemDefaults.TextStyles.BodyText
								}
							}
						}
					}        

					Container {
						visible: (sharesAccess.selectedValue == "anyone" || sharesAccess.selectedValue == "anyonewithlink")
						
						topMargin: 15.0
						horizontalAlignment: HorizontalAlignment.Fill
						
						Divider {
							horizontalAlignment: HorizontalAlignment.Fill
						}
					
						Container {
							bottomMargin: 15.0

							horizontalAlignment: HorizontalAlignment.Fill
						
							Button {
								text: qsTr("Share the link") + Retranslate.onLanguageChanged

								horizontalAlignment: HorizontalAlignment.Fill

								layoutProperties: StackLayoutProperties {
								}

								onClicked: {
									permissionsContainer.visible = false;
									buttonsContainer.visible = false;
									usersContainer.visible = false;
									errorContainer.visible = false;

									dataLoadIndicator.running = true;

									sendSharedLink();
								}
							}
						}
					}
				}
					
				Container {
					id: buttonsContainer
					objectName: "buttonsContainer"
					visible: false
					
					horizontalAlignment: HorizontalAlignment.Fill
						
					TextArea {
						text: qsTr(
							"Share the link with anyone to the file or the folder."
							) + Retranslate.onLanguageChanged

						editable: false
					}

					Container {
						objectName: "invokeListButtons"
		
						topPadding: 50
						leftPadding: 50
						rightPadding: 50
		
						horizontalAlignment: HorizontalAlignment.Fill
						verticalAlignment: VerticalAlignment.Top
						
						layout: StackLayout {
							orientation: LayoutOrientation.TopToBottom
						}
					}

					Container {
						objectName: "invokeError"

						visible: false

						topPadding: 50
						leftPadding: 50
						rightPadding: 50
		
						horizontalAlignment: HorizontalAlignment.Fill
						verticalAlignment: VerticalAlignment.Center
						
						layout: StackLayout {
							orientation: LayoutOrientation.TopToBottom
						}

						Label {
							text: qsTr("Internal error !") + Retranslate.onLanguageChanged
							
							horizontalAlignment: HorizontalAlignment.Left
							verticalAlignment: VerticalAlignment.Center
							
							textStyle {
								base: SystemDefaults.TextStyles.BodyText
							}
						}
					}
				}

				Container {
					id: usersContainer
					objectName: "usersContainer"
					visible: false
		
					horizontalAlignment: HorizontalAlignment.Fill
		
					layout: StackLayout {
					}
						
					layoutProperties: StackLayoutProperties {
					}

					Container {
						horizontalAlignment: HorizontalAlignment.Fill
							
						TextArea {
							text: qsTr(
								"Manage your collaborators list."
								) + Retranslate.onLanguageChanged

							editable: false
						}

						ActivityIndicator {
							id: usersLoadIndicator
							preferredWidth: 400
							preferredHeight: 400
							horizontalAlignment: HorizontalAlignment.Center
							verticalAlignment: VerticalAlignment.Top
							running: usersLoading
							visible: usersLoading
						}

						ListView {
							id: usersList
							objectName: "usersList"
							visible: !usersLoading

							horizontalAlignment: HorizontalAlignment.Fill
							verticalAlignment: VerticalAlignment.Top

							layout: StackListLayout {
								id: usersListLayout;
								headerMode: ListHeaderMode.None
							}

							layoutProperties: StackLayoutProperties {
							}
						
							dataModel: groupDataModel

							listItemComponents: [
								ListItemComponent {
									type: "item"
									GoogleDriveUserItem {
									}
								}
							]

							onTriggered: {
								clearSelection();
								select(indexPath);
							}

							function runAction(action, indexPath) {
								console.log("action detected !", action, indexPath);
								
								actionContactClicked(action, indexPath);
							}
						}
					}
				}

				Container {
					id: errorContainer
					objectName: "errorContainer"
					visible: false
		
					horizontalAlignment: HorizontalAlignment.Fill
		
					layout: StackLayout {
					}
						
					layoutProperties: StackLayoutProperties {
					}

					Label {
						text: qsTr("Connection failure !") + Retranslate.onLanguageChanged
	
						horizontalAlignment: HorizontalAlignment.Fill
	
						textStyle {
							base: SystemDefaults.TextStyles.BodyText
						}
					}
				}
			}
	    }
    }

	onCreationCompleted: {
		OrientationSupport.supportedDisplayOrientation = 
			SupportedDisplayOrientation.All;
	}

	function onPermissionsChanged() {
		sharePage.actionSave = false;

		permissionsChanged();
	}
}

