import bb.cascades 1.3

Container {
    id: filesContainer
    opacity: 1.0
    preferredWidth: 1440.0

    layout: DockLayout {
    }

    Container {
        id: background
        background: Color.create("#3d4750")
        visible: false

		horizontalAlignment: HorizontalAlignment.Fill
		verticalAlignment: VerticalAlignment.Fill

        layout: DockLayout {
        }
    }
        
    // The Item content an image and a text.
    Container {
		leftPadding: 3
		topPadding: 10.0
		bottomPadding: 10.0

		horizontalAlignment: HorizontalAlignment.Fill

        layout: StackLayout {
            orientation: LayoutOrientation.LeftToRight
        }
        
        ImageView {
            preferredWidth: 60.0 * filesContainer.ListItem.view.nbrInfoLines
            preferredHeight: 60.0 * filesContainer.ListItem.view.nbrInfoLines

			minWidth: preferredWidth
			minHeight: preferredHeight
            
			horizontalAlignment: HorizontalAlignment.Center
			verticalAlignment: VerticalAlignment.Center

            // The image is bound to the data in models/recipemodel.xml image attribute.
            imageSource: ListItemData.icon
        	scalingMethod: ScalingMethod.AspectFit
            
            layoutProperties: StackLayoutProperties {
            }
            
            leftMargin: 10.0
            rightMargin: 10.0
            bottomMargin: 10.0
            topMargin: 10.0
        }

		Container {
			horizontalAlignment: HorizontalAlignment.Fill
			verticalAlignment: VerticalAlignment.Center

			layout: StackLayout {
				orientation: LayoutOrientation.TopToBottom
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.name
				leftMargin: 20.0

				horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.SubtitleText // BodyText SubtitleText SmallText
                	color: Color.create("#b9c2cc")
				}
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.date
				leftMargin: 20.0

                visible: (filesContainer.ListItem.view.nbrInfoLines > 1)

				horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.SmallText // BodyText SubtitleText SmallText
                	color: Color.create("#b9c2cc")
					fontStyle: FontStyle.Italic
				}
			}
        
			Label {
				// The title is bound to the data in models/recipemodel.xml title attribute.
				text: ListItemData.size
				leftMargin: 20.0

                visible: (filesContainer.ListItem.view.nbrInfoLines > 2)

				horizontalAlignment: HorizontalAlignment.Left
				verticalAlignment: VerticalAlignment.Center

				textStyle {
					base: SystemDefaults.TextStyles.SmallText // BodyText SubtitleText SmallText
                	color: Color.create("#b9c2cc")
					fontStyle: FontStyle.Italic
				}
			}
		}
    }
    

    contextActions: [
        ActionSet {
            title: ListItemData.name
            subtitle: qsTr("File action") + Retranslate.onLanguageChanged
            
            ActionItem {
                title: qsTr("Rename") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/rename.png"
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_RENAME", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "e"
					}
				]
            }
            
            ActionItem {
                title: qsTr("Open with...") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/openwith.png"
				enabled: ListItemData.openable
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_OPENWITH", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "o"
					}
				]
            }
            
            ActionItem {
                title: qsTr("Copy to") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/copy.png"
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_COPY", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "c"
					}
				]
            }

            ActionItem {
                title: qsTr("Move to") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/move.png"
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_MOVE", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "m"
					}
				]
            }

            ActionItem {
                title: qsTr("Print") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/print.png"
            	enabled: ListItemData.printable
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_PRINT", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "p"
					}
				]
            }

            ActionItem {
                title: qsTr("Hide / Show") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/hide.png"
            	enabled: ListItemData.hideable
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_HIDDEN", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "h"
					}
				]
            }

//            ActionItem {
//                enabled: false
//                title: qsTr("Zip") + Retranslate.onLanguageChanged
//                imageSource: "asset:///images/dock/zip.png"
//                onTriggered: {
//                    filesContainer.ListItem.view.runAction("ACTION_ZIP", filesContainer.ListItem.indexPath);
//                }
//            }

//            ActionItem {
//				enabled: false
//                title: qsTr("Crypt") + Retranslate.onLanguageChanged
//                imageSource: "asset:///images/dock/crypt.png"
//                onTriggered: {
//                    filesContainer.ListItem.view.runAction("ACTION_CRYPT", filesContainer.ListItem.indexPath);
//                }
//            }

            ActionItem {
                title: qsTr("Share") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/share.png"
				enabled: ListItemData.shareable
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_SHARE", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "s"
					}
				]
            }

            ActionItem {
                title: qsTr("Add bookmark") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/addbookmarks.png"
            	enabled: ListItemData.isfolder
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_BOOKMARKS", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "f"
					}
				]
            }

            ActionItem {
                title: qsTr("Details") + Retranslate.onLanguageChanged
                imageSource: "asset:///images/dock/info.png"
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_INFO", filesContainer.ListItem.indexPath);
                }
				shortcuts: [
					Shortcut {
						key: "i"
					}
				]
            }

			MultiSelectActionItem {
				multiSelectHandler: filesContainer.ListItem.view.multiSelectHandler
				onTriggered: {
					multiSelectHandler.active;    
				} 
			}

			ActionItem {
				title: qsTr("Select all") + Retranslate.onLanguageChanged
				imageSource: "asset:///images/dock/selectall.png"
				onTriggered: {
	               filesContainer.ListItem.view.runAction("ACTION_SELECTALL", filesContainer.ListItem.indexPath); 
				}
			}

            DeleteActionItem {
                title: qsTr("Delete") + Retranslate.onLanguageChanged
                onTriggered: {
                    filesContainer.ListItem.view.runAction("ACTION_DELETE", filesContainer.ListItem.indexPath);
                }
            }
        }
    ]

    // Both the activation and selection of an item has the same visual appearance.
    function setHighlight (highlighted) {
        if (highlighted) {
//            filesContainer.opacity = 0.7;
            background.visible = true;
        } else {
//            filesContainer.opacity = 1.0;
            background.visible = false;
        }
    }

    // Signal handler for list item activation.    
    ListItem.onActivationChanged: {
		console.log("active changed");
        setHighlight (ListItem.active);
    }
    
    // Signal handler for list item selection.
    ListItem.onSelectionChanged: {
		console.log("select changed");
        setHighlight (ListItem.selected);
    }
    
    scaleX: 1.0
    scaleY: 1.0
}
